@@ -1,26 +1,43 @@
+use 5.006;    # our
 use strict;
 use warnings;
 
 package Dist::Zilla::Role::PrereqSource::External;
-BEGIN {
-  $Dist::Zilla::Role::PrereqSource::External::AUTHORITY = 'cpan:KENTNL';
-}
-{
-  $Dist::Zilla::Role::PrereqSource::External::VERSION = '0.2.4';
-}
+
+our $VERSION = 'v0.3.0';
+
+our $AUTHORITY = 'cpan:KENTNL'; # AUTHORITY
 
 # FILENAME: External.pm
 # CREATED: 30/10/11 10:56:47 by Kent Fredric (kentnl) <kentfredric@gmail.com>
 # ABSTRACT: A plugin that depends on DarkPAN/External sources
 
-use Moose::Role;
+use Moose::Role qw( with requires around );
 with 'Dist::Zilla::Role::Plugin';
 
 
+
+
+
+
+
+
+
+
+
+
+
 use namespace::autoclean;
 
 requires 'register_external_prereqs';
 
+around dump_config => sub {
+  my ( $orig, $self, @args ) = @_;
+  my $config = $self->$orig(@args);
+  $config->{ +__PACKAGE__ }->{ q[$] . __PACKAGE__ . q[::VERSION] } = $VERSION;
+  return $config;
+};
+
 no Moose::Role;
 1;
 
@@ -36,7 +53,7 @@ Dist::Zilla::Role::PrereqSource::External - A plugin that depends on DarkPAN/Ext
 
 =head1 VERSION
 
-version 0.2.4
+version v0.3.0
 
 =begin MetaPOD::JSON v1.1.0
 
@@ -55,7 +72,7 @@ Kent Fredric <kentnl@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Kent Fredric <kentnl@cpan.org>.
+This software is copyright (c) 2017 by Kent Fredric <kentnl@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
